==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Edit/DrawingPreferences/UnitSettings/ts/UnitSettings_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja_JP">
<context>
    <name>UnitSettings</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Drawing Unit:</source>
        <translation>図面単位:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Paper Unit:</source>
        <translation>用紙単位:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Measurement System (for line types and hatch patterns):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../UnitSettings.js" line="+27"/>
        <source>Defaults for New Drawings</source>
        <translation>新規図面へのデフォルト</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+2"/>
        <source>Drawing Unit</source>
        <translation>図面単位</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>General</source>
        <translation>一般</translation>
    </message>
    <message>
        <location line="+71"/>
        <source>None</source>
        <translation>なし</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Inch</source>
        <translation>インチ</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Foot</source>
        <translation>フィート</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Mile</source>
        <translation>マイル</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Millimeter</source>
        <translation>ミリメートル</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Centimeter</source>
        <translation>センチメートル</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Meter</source>
        <translation>メートル</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Kilometer</source>
        <translation>キロメートル</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Microinch</source>
        <translation>マイクロインチ</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Mil</source>
        <translation>ミル</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Yard</source>
        <translation>ヤード</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Angstrom</source>
        <translation>オングストローム</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Nanometer</source>
        <translation>ナノメートル</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Micron</source>
        <translation>ミクロン</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Decimeter</source>
        <translation>デシメートル</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Decameter</source>
        <translation>デカメートル</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Hectometer</source>
        <translation>ヘクトメートル</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Gigameter</source>
        <translation>ギガメートル</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Astro</source>
        <translation>アストロ</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Lightyear</source>
        <translation>光年</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Parsec</source>
        <translation>パーセク</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Imperial</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Metric</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Edit/DrawingPreferences/UnitSettings/ts/UnitSettings_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>UnitSettings</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Drawing Unit:</source>
        <translation>図面単位:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Paper Unit:</source>
        <translation>用紙単位:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Measurement System (for line types and hatch patterns):</source>
        <translation>測定系（ラインタイプとハッチパターンのため）</translation>
    </message>
    <message>
        <location filename="../UnitSettings.js" line="+27"/>
        <source>Defaults for New Drawings</source>
        <translation>新規図面へのデフォルト</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+2"/>
        <source>Drawing Unit</source>
        <translation>図面単位</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>General</source>
        <translation>一般</translation>
    </message>
    <message>
        <location line="+71"/>
        <source>None</source>
        <translation>なし</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Inch</source>
        <translation>インチ</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Foot</source>
        <translation>フィート</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Mile</source>
        <translation>マイル</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Millimeter</source>
        <translation>ミリメートル</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Centimeter</source>
        <translation>センチメートル</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Meter</source>
        <translation>メートル</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Kilometer</source>
        <translation>キロメートル</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Microinch</source>
        <translation>マイクロインチ</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Mil</source>
        <translation>ミル</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Yard</source>
        <translation>ヤード</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Angstrom</source>
        <translation>オングストローム</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Nanometer</source>
        <translation>ナノメートル</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Micron</source>
        <translation>ミクロン</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Decimeter</source>
        <translation>デシメートル</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Decameter</source>
        <translation>デカメートル</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Hectometer</source>
        <translation>ヘクトメートル</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Gigameter</source>
        <translation>ギガメートル</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Astro</source>
        <translation>アストロ</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Lightyear</source>
        <translation>光年</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Parsec</source>
        <translation>パーセク</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Imperial</source>
        <translation>ヤード・ポンド法</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Metric</source>
        <translation>メートル法</translation>
    </message>
</context>
</TS>
